#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"

for f in ${SCRIPT_DIR}/../../lib/*.bash; do source "$f"; done

INIT_STATE_FILE="/opt/open-xchange/etc/20-init-middleware-done"

if [ ! -f ${INIT_STATE_FILE} ]; then

    echo "Initializing this middleware "
    # Increasing rate limit...
    # setting default config (key, value, filepath)
    # Set sieve server
    setOXProperty com.openexchange.mail.filter.server "${OX_MAIL_HOST}" /opt/open-xchange/etc/mailfilter.properties 
    # Enabling Chronos owner change...
    # setOXProperty io.ox/calendar//chronos/allowChangeOfOrganizer true /opt/open-xchange/etc/settings/appsuite.properties
    setOXProperty com.openexchange.calendar.allowChangeOfOrganizer true /opt/open-xchange/etc/calendar.properties
    # setOXProperty for sharing to frontend 
    setOXProperty com.openexchange.share.guestHostname "${HOST_NAME}" /opt/open-xchange/etc/share.properties
    setOXProperty io.ox/tours//server/disableTours true /opt/open-xchange/etc/settings/guidedtours.properties	
    setOXProperty io.ox/core//wizards/firstStart/finished true /opt/open-xchange/etc/settings/guidedtours.properties
    setOXProperty io.ox/tours//server/startOnFirstLogin false /opt/open-xchange/etc/settings/guidedtours.properties
    setOXProperty io.ox/tours//whatsNew/neverShowAgain true /opt/open-xchange/etc/settings/guidedtours.properties
    # Enable filestorage provider
    setOXProperty com.openexchange.capability.filestorage_webdav true /opt/open-xchange/etc/filestorage.properties
    setOXProperty com.openexchange.capability.filestorage_owncloud true /opt/open-xchange/etc/filestorage.properties
    setOXProperty com.openexchange.capability.filestorage_nextcloud true /opt/open-xchange/etc/filestorage.properties
    
    # Enable deputy management
    if [[ -f /usr/share/doc/open-xchange-deputy/properties/deputy.properties.gz ]]; then
      echo "Unzipping default deputy.properties file ..."
      /bin/gunzip -fv /usr/share/doc/open-xchange-deputy/properties/deputy.properties.gz
    fi

    if [[ -f /usr/share/doc/open-xchange-deputy/properties/deputy.properties ]]; then
      echo "Copying over default deputy.properties file ..."
      /bin/cp -vf /usr/share/doc/open-xchange-deputy/properties/deputy.properties /opt/open-xchange/etc/deputy.properties
    fi
    setOXProperty com.openexchange.deputy.enabled true /opt/open-xchange/etc/deputy.properties

    echo "Waiting for database service ..."
    waitPort ${DATABASE_HOST_NAME} ${DATABASE_HOST_PORT}

    # restart of OX service is required at this time and can not be skipped
    restartService open-xchange

    sleep 10
    waitTillAppsuiteReady

    # setting propper filestore permissions ...
    mkdir -p /var/opt/filestore
    chown -R open-xchange:open-xchange /var/opt/filestore


    /opt/open-xchange/sbin/registerserver -n "${OX_SERVER_NAME}" \
        -A "${OX_ADMINMASTER_USER}" \
        -P "${OX_ADMINMASTER_PASS}" > /opt/open-xchange/etc/20-registerserver.out
    export OX_SERVER_ID=$(cat /opt/open-xchange/etc/20-registerserver.out | awk '{ print $2 }')

    echo "Creating filestore at /var/opt/filestore (you may mount some external storage there ...)"

    /opt/open-xchange/sbin/registerfilestore -t file:///var/opt/filestore \
        -A "${OX_ADMINMASTER_USER}" \
        -P "${OX_ADMINMASTER_PASS}" > /opt/open-xchange/etc/20-registerfilestore.out
    export OX_FILESTORE_ID=$(cat /opt/open-xchange/etc/20-registerfilestore.out | awk '{ print $2 }')

    echo "Registering oxdatabase ..."
    # register master database
    /opt/open-xchange/sbin/registerdatabase \
        -A "${OX_ADMINMASTER_USER}" \
        -P "${OX_ADMINMASTER_PASS}" \
        --hostname "${DATABASE_HOST_NAME}" \
        --dbuser "${DATABASE_CONFIGDB_USER}" \
        --dbpasswd "${DATABASE_CONFIGDB_PASS}" \
        --master "true" \
        --name "oxdatabase" > /opt/open-xchange/etc/20-registermasterdatabase.out
    export OX_DATABASE_MASTER_ID=$(cat /opt/open-xchange/etc/20-registermasterdatabase.out | awk '{ print $2 }')
    
    echo "Registering globaldb ..."
    # register globaldb
    /opt/open-xchange/sbin/registerdatabase \
        -A "${OX_ADMINMASTER_USER}" \
        -P "${OX_ADMINMASTER_PASS}" \
        --hostname "${DATABASE_HOST_NAME}" \
        --dbuser "${DATABASE_CONFIGDB_USER}" \
        --dbpasswd "${DATABASE_CONFIGDB_PASS}" \
        --master "true" \
        --name "oxglobal" \
        --maxunit 0 > /opt/open-xchange/etc/20-registerglobaldatabase.out
    export OX_DATABASE_GLOBAL_ID=$(cat /opt/open-xchange/etc/20-registerglobaldatabase.out | awk '{ print $2 }')

    

    echo "Setting globaldb id in /opt/open-xchange/etc/globaldb.yml to '$OX_DATABASE_GLOBAL_ID'"
    sed -i "s/id:.*/id: '$OX_DATABASE_GLOBAL_ID'/g" /opt/open-xchange/etc/globaldb.yml

    echo "Successfully ${RE_INIT_TAG}initialized environment..."
    echo "Server name:  "$OX_SERVER_NAME
    echo "Server id:    "$OX_SERVER_ID
    echo "Filestore ID: "$OX_FILESTORE_ID
    echo "Master DB ID: "$OX_DATABASE_MASTER_ID
    echo "Global DB ID: "$OX_DATABASE_GLOBAL_ID
    echo "===================================================="

    echo "$(date)" > ${INIT_STATE_FILE}
    
else
    echo "WARNING: This scripts has already been executed and will be skipped!"
    sleep 5
fi

cat ${INIT_STATE_FILE}


