  #!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"

# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../../lib/*.bash; do source "$f"; done
checkRootPrivileges
detectDistribution
# sourcing the default configuration to use
# source ${SCRIPT_DIR}/config
## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

# Restart tof ox only. Add other file for different services (e.g. do not restart everything if not necessary)
if [ -f "/opt/open-xchange/etc/000-ox-restart-required" ]; then
  if [ -f "/var/log/open-xchange/open-xchange-osgi.log" ]; then
    # renaming existing osgi log which sometimes exists after initial setup
    echo "### OSGI Log present after initial setup - moving it now ..."
    mv /var/log/open-xchange/open-xchange-osgi.log /var/log/open-xchange/open-xchange-osgi.log.setup
    sleep 5
  fi

  echo "### OX service restart is required since the file exists: /opt/open-xchange/etc/000-ox-restart-required" 
  waitPort localhost 8009

  restartService open-xchange
  rm -f /opt/open-xchange/etc/000-ox-restart-required
  echo ""
  
  waitTillAppsuiteReady

  echo "Trying to execute all updates tasks ..."
  /opt/open-xchange/sbin/runallupdate -A ${OX_ADMINMASTER_USER} -P ${OX_ADMINMASTER_PASS}
fi