
#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <daniel.pondruff@open-xchange.com>
#

set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
checkRootPrivileges
detectDistribution
if [ "$CONFIG_LOADED" != true ] ; then
  loadConfig
fi
## Help text
show_usage() {
echo -n "
This script lets you enable or disable the java security manager. A restart is required (either set the --restart option or restart manually)

  $0 [OPTIONS]
  
    --enable
    --disable
    --restart

"
}


### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --enable)
    FEATURE_ENABLE=true
    shift
    ;;
    --disable)
    FEATURE_ENABLE=false
    shift
    ;;
    --restart)
    RESTART_OX=true
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


if [[ "${FEATURE_JAVA_SECURITY_MANAGER}" = true  ]]; then
  if [[ "${FEATURE_ENABLE}" = true  ]]; then
    echo "Enabling Java Security Manager ... "
    sed -e '/JAVA_OPTS_SECURITY/ s/^#*//g' -i /opt/open-xchange/etc/ox-scriptconf.sh 
    
    # TODO: check if restart file exists and actually restart it
    touch /opt/open-xchange/etc/000-ox-restart-required
  elif [[ "${FEATURE_ENABLE}" = false  ]]; then
    echo "Disable Java Security Manager"
    sed -e '/JAVA_OPTS_SECURITY/ s/^#*/#/g' -i /opt/open-xchange/etc/ox-scriptconf.sh  

    # TODO: check if restart file exists and actually restart it
    touch /opt/open-xchange/etc/000-ox-restart-required
  fi
else
  echo "Skipping feature java security manager ..."
  echo ""
  sleep 3
fi

if [[ "${RESTART_OX}" = true  ]]; then
  echo "### Restart forced by script option ... "
  restartService open-xchange
fi