
#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <daniel.pondruff@open-xchange.com>
#

set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
checkRootPrivileges
detectDistribution

## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]
  
    --enable
    --disable
    --restart
    --install

"
}


### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --enable)
    FEATURE_ENABLE=true
    shift
    ;;
    --disable)
    FEATURE_ENABLE=false
    shift
    ;;
    --install)
    FEATURE_INSTALL=true
    shift
    ;;
    --restart)
    RESTART_OX=true
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters



if [[ "${FEATURE_USERFEEDBACK}" = true  ]]; then
  if [[ "${FEATURE_INSTALL}" = true  ]]; then  
    echo "Installing userfeedback packages ..."
    installPackagesRetry "open-xchange-userfeedback"
  fi

  if [[ "${FEATURE_ENABLE}" = true  ]]; then  

    echo "Enable userfeedback ..."
    setOXProperty com.openexchange.userfeedback.enabled true /opt/open-xchange/etc/userfeedbackmail.properties
    setOXProperty com.openexchange.userfeedback.mail.senderAddress "${OX_ENV_NOREPLY_ADDRESS}" /opt/open-xchange/etc/userfeedbackmail.properties
    
    setOXProperty com.openexchange.userfeedback.mail.senderName "Userfeedback" /opt/open-xchange/etc/userfeedbackmail.properties
    setOXProperty com.openexchange.userfeedback.mail.senderAddress "${OX_ENV_NOREPLY_ADDRESS}" /opt/open-xchange/etc/userfeedbackmail.properties

    setOXProperty com.openexchange.userfeedback.smtp.hostname "${OX_ENV_NOREPLY_SERVER}" /opt/open-xchange/etc/userfeedbackmail.properties
    setOXProperty com.openexchange.userfeedback.smtp.port 25 /opt/open-xchange/etc/userfeedbackmail.properties
    setOXProperty com.openexchange.userfeedback.smtp.username "${OX_ENV_NOREPLY_LOGIN}" /opt/open-xchange/etc/userfeedbackmail.properties
    setOXProperty com.openexchange.userfeedback.smtp.password "${OX_ENV_NOREPLY_PASSWORD}" /opt/open-xchange/etc/userfeedbackmail.properties

    # Touching restart required flag 
    touch /opt/open-xchange/etc/000-ox-restart-required
  elif [[ "${FEATURE_ENABLE}" = false  ]]; then  
    echo "Disable userfeedback ..."
    setOXProperty com.openexchange.userfeedback.enabled false /opt/open-xchange/etc/userfeedbackmail.properties
    
    echo "Reloading ox config ..."
    /opt/open-xchange/sbin/reloadconfiguration
  fi
else
  echo "Skipping userfeedback ..."
  echo ""
  sleep 3
fi

if [[ "${RESTART_OX}" = true  ]]; then
  echo "### Restart forced by script option ... "
  restartService open-xchange
fi
