
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#

# This restarts the provided service name with the configured service managers
function restartService {

    echo "Restarting service $1 ..."    
    if [[ "${DIST}" == "RHEL7" ]]; then
        systemctl restart $1.service
    else
        service $1 restart
    fi

}
function startAllServices {
    checkInstalled
    if [[ true == "${MIDDLEWARE_INSTALLED}" ]]; then
        restartService open-xchange
    fi
    if [[ true == "${IMAGECONVERTER_INSTALLED}" ]]; then
        restartService open-xchange-imageconverter-server
    fi
    if [[ true == "${DOCUMENTS_COLLABORATION_INSTALLED}" ]]; then
        restartService open-xchange-documents-collaboration
    fi
    if [[ true == "${DOCUMENTCONVERTER_INSTALLED}" ]]; then
        restartService open-xchange-documentconverter-server
    fi
    if [[ true == "${SPELLCHECK_INSTALLED}" ]]; then
        restartService open-xchange-spellcheck
    fi
}
function stopService {
    
    echo "Stopping service $1 ..."    
    if [[ "${DIST}" == "RHEL7" ]]; then
        systemctl stop $1.service
    else
        service $1 stop
    fi

}
function stopAllServices {
    checkInstalled
    if [[ true == "${MIDDLEWARE_INSTALLED}" ]]; then
        stopService open-xchange
    fi
    if [[ true == "${IMAGECONVERTER_INSTALLED}" ]]; then
        stopService open-xchange-imageconverter-server
    fi
    if [[ true == "${DOCUMENTS_COLLABORATION_INSTALLED}" ]]; then
        stopService open-xchange-documents-collaboration
    fi
    if [[ true == "${DOCUMENTCONVERTER_INSTALLED}" ]]; then
        stopService open-xchange-documentconverter-server
    fi

}

function detectDistribution {
    if [[ -f /etc/debian_version ]]; then
        REV=$(cat /etc/debian_version)
        if [[ "${REV}" == "9."* ]]; then
            export DIST="DebianStretch"
            export DIST_VERSION="stretch"
            export ANY_DEB=true
            export HTTPD="apache2"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf-enabled/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/sites-enabled/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=\$\{APACHE_LOG_DIR\}
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/ssl/certs/ssl-cert-snakeoil.pem
            export HTTPD_TLS_KEY=/etc/ssl/private/ssl-cert-snakeoil.key
            export DISTRO="DebianStretch"
            export DISTRO_GENERIC="debian"
            export COMPATIBLE=true
        elif [[ "${REV}" == "10."* ]]; then
            export DIST="DebianBuster"
            export DIST_VERSION="buster"
            export ANY_DEB=true
            export HTTPD="apache2"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf-enabled/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/sites-enabled/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=\$\{APACHE_LOG_DIR\}
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/ssl/certs/ssl-cert-snakeoil.pem
            export HTTPD_TLS_KEY=/etc/ssl/private/ssl-cert-snakeoil.key
            export DISTRO="DebianBuster"
            export DISTRO_GENERIC="debian"
            export COMPATIBLE=true
        elif [[ "${REV}" == "11."* ]]; then
            export DIST="DebianBullseye"
            export DIST_VERSION="bullseye"
            export ANY_DEB=true
            export HTTPD="apache2"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf-enabled/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/sites-enabled/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=\$\{APACHE_LOG_DIR\}
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/ssl/certs/ssl-cert-snakeoil.pem
            export HTTPD_TLS_KEY=/etc/ssl/private/ssl-cert-snakeoil.key
            export DISTRO="DebianBullseye"
            export DISTRO_GENERIC="debian"
            export COMPATIBLE=true
        elif [[ "${REV}" == "12."* ]]; then
            export DIST="DebianBookworm"
            export DIST_VERSION="bookworm"
            export ANY_DEB=true
            export HTTPD="apache2"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf-enabled/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/sites-enabled/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=\$\{APACHE_LOG_DIR\}
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/ssl/certs/ssl-cert-snakeoil.pem
            export HTTPD_TLS_KEY=/etc/ssl/private/ssl-cert-snakeoil.key
            export DISTRO="DebianBookworm"
            export DISTRO_GENERIC="debian"
            export COMPATIBLE=true  
        fi
        export DEBIAN_FRONTEND=noninteractive

    elif [[ -f /etc/redhat-release ]]; then
        DISTRO_GENERIC="rhel"
        REV=$(sed -E 's/.*Red\ Hat\ Enterprise\ Linux( Server)? release\ //' < /etc/redhat-release | sed s/\ .*//)
        if [[ "${REV}" == "6."* ]]; then
            export DIST="RHEL6"
            export DIST_VERSION="6"
            export ANY_RPM=true
            export ANY_RHEL=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL6"
            export DISTRO_GENERIC="rhel"
            export COMPATIBLE=false
        elif [[ "${REV}" == "7."* ]]; then
            export DIST="RHEL7"
            export DIST_VERSION="7"
            export ANY_RPM=true
            export ANY_RHEL=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL7"
            export DISTRO_GENERIC="rhel"
            export COMPATIBLE=true
        elif [[ "${REV}" == "8."* ]]; then
            export DIST="RHEL8"
            export DIST_VERSION="8"
            export ANY_RPM=true
            export ANY_RHEL=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL8"
            export DISTRO_GENERIC="rhel"
            export COMPATIBLE=true
        fi
        DISTRO_GENERIC="centos"
        REV=$(sed s/.*CentOS\ release\ // < /etc/redhat-release | sed s/\ .*//)
        if [[ "${REV}" == "6."* ]]; then
            export DIST="CENTOS6"
            export DIST_VERSION="6"
            export ANY_RPM=true
            export ANY_CENTOS=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL6"
            export DISTRO_GENERIC="centos"
            export COMPATIBLE=false
        fi
        REV=$(sed s/.*CentOS\ Linux\ release\ // < /etc/redhat-release | sed s/\ .*//)
        if [[ "${REV}" == "7."* ]]; then
            export DIST="CENTOS7"
            export DIST_VERSION="7"
            export ANY_RPM=true
            export ANY_CENTOS=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL7"
            export DISTRO_GENERIC="centos"
            export COMPATIBLE=true
        fi
        REV=$(sed s/.*CentOS\ Stream\ release\ // < /etc/redhat-release | sed s/\ .*//)
        if [[ "${REV}" == "8"* ]]; then
            export DIST="CENTOS8"
            export DIST_VERSION="8"
            export ANY_RPM=true
            export ANY_CENTOS=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL8"
            export DISTRO_GENERIC="centos"
            export COMPATIBLE=true
        fi

    elif [[ -f /etc/os-release ]]; then
        declare -A OSRELEASE

        while IFS='=' read -r col1 col2
        do
          OSRELEASE[$col1]="${col2//\"/}"
        done </etc/os-release

        if [[ ${OSRELEASE[ID]} == amzn  && ${OSRELEASE[VERSION_ID]} == 2 ]]
        then
            # Amazon Linux 2
            export DIST="RHEL7"
            export DIST_VERSION="7"
            export ANY_RPM=true
            export ANY_RHEL=true
            export HTTPD="httpd"
            export HTTPD_CONF_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_SITES_PATH=/etc/${HTTPD}/conf.d/
            export HTTPD_WWWROOT_PATH=/var/www/html
            export HTTPD_LOG_PATH=logs
            export HTTPD_TLS_CIPHERS='ECDH+AESGCM:ECDH+AES256:ECDH+AES128:!aNULL'
            export HTTPD_TLS_PROTOCOLS='-all +TLSv1 +TLSv1.1 +TLSv1.2'
            export HTTPD_TLS_CRT=/etc/pki/tls/certs/localhost.crt
            export HTTPD_TLS_KEY=/etc/pki/tls/private/localhost.key
            export DISTRO="RHEL7"
            export DISTRO_GENERIC="rhel"
            export COMPATIBLE=true
        fi
    fi
    if [[ "${COMPATIBLE}" != true ]]; then
        echo "unknown."
        echo ""
        echo "Supported platforms:"
        echo "* Debian GNU/Linux 9 (Stretch)"
        echo "* Debian GNU/Linux 10 (Buster)"
        echo "* Debian GNU/Linux 11 (Bullseye)"
        echo "* Debian GNU/Linux 12 (Bookworm)"
        echo "* RedHat Enterprise Linux 7 (RHEL7)"
        echo "* RedHat Enterprise Linux 8 (RHEL8)"
        echo "* Amazon Linux 2"
        echo "* CentOS 7"
        echo "Unsupported platforms:"
        echo "* RedHat Enterprise Linux 6 (RHEL6)"
        echo "* CentOS 6"
        echo "* Novell SuSE Linux Enterprise Server"
        exit 1
    fi
}

function checkRootPrivileges {
    echo -n "Checking user..."
    if [[ $(whoami) != "root" ]]; then
        echo "Failed."
        echo "Please run this script as superuser (root)."
        exit 1
    else
        echo "OK."
    fi
}

function setOXProperty {
    # key value file
    if [ ! -f /opt/open-xchange/lib/oxfunctions.sh ]; then
        echo "ERROR: oxfunctions.sh file does not exist"
        exit 1
    fi

    source /opt/open-xchange/lib/oxfunctions.sh

    if [ ! -f $3 ]; then
        echo "File $3 does not exist ... creating ..."
        touch $3
    fi

    echo "Setting ox property: $@"
    ox_set_property "$@"
}

function waitPort {
  echo "Waiting for port $2 on host $1 ..."
  
  while ! timeout 1s /bin/bash -c "2>/dev/null >/dev/tcp/$1/$2"; do 
    sleep 1 
    echo ". "
  done


  echo "Port available"
}

function exportProperties {

    if [ -f "$1" ]
    then


    while IFS='=' read -r key value
    do
        if [[ $key != \#* ]] && [[ -n $key ]] ; then   
            export $key=$(eval echo "$value")
        fi

    done < "$1"

    else
        echo "ERROR: $1 not found."
        echo ""
        sleep 3
    fi
}

function waitTillAppsuiteReady {
    set +e
    echo "Waiting till App Suite health checker returns 200 ... "
    timeout 300 bash -c 'while [[ "$(curl -s -o /dev/null -w ''%{http_code}'' localhost:8009/health)" != "200" ]]; do echo "." && sleep 5; done' || false
    set -e
}



function loadConfig {
    # temporary enabling extended shell debugging to retrieve functions definition location - in this case myself ...
    if [[ -z "$INSTALLER_ROOT" ]] ; then
        shopt -s extdebug
        declaration_location=$(declare -F loadConfig | awk '{ print $3 } ')
        declaration_location=$(readlink -f ${declaration_location})
        export INSTALLER_ROOT=${declaration_location/\/lib\/common.bash/}
        shopt -u extdebug
    fi
    # sourcing the default configuration to use
    # This may be overriden by some arguments below
    # This config file will still be loaded to provide defaults
    # exportProperties ${SCRIPT_DIR}/config/config
    exportProperties ${INSTALLER_ROOT}/setup/versions
    if [[ -z "$CONFIG_FILE" ]] ; then
        echo "CONFIG_FILE variable is empty, fallback to ${INSTALLER_ROOT}/config/config"
        export CONFIG_FILE="${INSTALLER_ROOT}/config/config"
    else
        echo "CONFIG_FILE variable set, using $CONFIG_FILE"
    fi
    exportProperties ${CONFIG_FILE}

    if [[ -z "$CONFIG_EXTENDED_FILE" ]] ; then
        echo "CONFIG_EXTENDED_FILE variable is empty, fallback to ${INSTALLER_ROOT}/config/config.extended"
        export CONFIG_EXTENDED_FILE="${INSTALLER_ROOT}/config/config.extended"
    else
        echo "CONFIG_EXTENDED_FILE variable set, using $CONFIG_EXTENDED_FILE"
    fi
    exportProperties ${CONFIG_EXTENDED_FILE}

    echo "Determine repository server to be used ..."
    if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
        echo "... using internal buildservice as repo source"
        export REPOSITORY_SERVER="http://buildservice.open-xchange.com"
    elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then
        if [[ -n "${AS_USER}" ]]; then
            echo "... using public software.ox.com as repo source (with credentials)"
            export REPOSITORY_SERVER="https://${AS_USER}:${AS_PASS}@software.open-xchange.com/products"
            export REPOSITORY_USE_UPDATES=true
        else
            echo "... using public software.ox.com as repo source"
            export REPOSITORY_SERVER="https://software.open-xchange.com/products"
        fi
    fi

    export CONFIG_LOADED=true
}