#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
#
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
#
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
# This collection contains functions for writing repositories. 
# Each function can be called manually, checks if the corresponding feature is enabled or if the global override is active and writes out the repositoreies as required
#
# TODO: move over setRepositories method or at least split that up as well

# function writeRepositoryTemplate {

# #NOTE: Check writeFrontendRepository for an propper example!
#     if [[ true == "${FEATURE_FLAG}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
#         # Take care if update dir has to be used        
#         if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
#             # internal buildservice format
#             AS_REPO_FEATURE="${REPOSITORY_SERVER}/FEATURE_NAME-${AS_FEATURE_VERSION}/"
#         elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
#             # public repo format
#             AS_REPO_FEATURE="${REPOSITORY_SERVER}/PATH_PART/${AS_FEATURE_VERSION}/PATH_PART2/"
#         else
#             echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
#             exit 99
#         fi
#         writeRepositoryFile "ox-feature" "${AS_REPO_FEATURE}" 
#     fi
# }

function writeRepositoryFile {

    # putting positional property into named propety for convinience
    REPO_FILE_NAME="$1"
    REPO_URL_PART="$2"
    ABSOLUTE_URL=$3

    # a little hacky ... if append = false or unset (so !=true) remove targed file prior to writing
    if [[ "${ABSOLUTE_URL}" != true ]]; then
        URL_SUFFIX="${DISTRO}/"
    fi

    if [[ true == "${REPOSITORY_USE_UPDATES}" ]]; then
        REPO_URL="${REPO_URL_PART}/updates/${URL_SUFFIX}"
    else 
        REPO_URL="${REPO_URL_PART}/${URL_SUFFIX}"
    fi

    echo "Cleaning old sources list created by this script ..."
    if [[ true == "${ANY_DEB}" ]]; then
            rm "/etc/apt/sources.list.d/${REPO_FILE_NAME}.list"  2> /dev/null || true
    elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then    
            rm "/etc/yum.repos.d/${REPO_FILE_NAME}.repo" 2> /dev/null || true
    fi

    echo "Writing repo file for $REPO_FILE_NAME ($REPO_URL)"
    if [[ true == "${ANY_DEB}" ]]; then
        echo "deb ${REPO_URL} /" >> "/etc/apt/sources.list.d/${REPO_FILE_NAME}.list"
    elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
        {
        echo "[${REPO_FILE_NAME}]"
        echo "name=${REPO_FILE_NAME}"
        echo "baseurl=${REPO_URL}"
        echo "enabled=1"
        echo "proxy=_none_"
        } >> "/etc/yum.repos.d/${REPO_FILE_NAME}.repo"

    fi 

}

function writeRepositories {
   
    echo "Determining and writing repository files according to the configuration at $CONFIG_FILE"
    writeFrontendRepository
    writeBackendRepository
    writeGuardRepository
    writeDriveClientRepositories
    writeUsmEasRepositories
    writeOfficeRepository
    writeOfficeWebRepository
    writeDocumentsCollaborationRepository
    writeDocumentconverterRepositories
    writeDocumentconverterApiRepository
    writeImageConverterRepository
    writeSpellcheckRepository
    writeWeakforceRepository

}


function writeFrontendRepository {

    if [[ true == "${INSTALL_FRONTEND}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_FRONTEND="${REPOSITORY_SERVER}/frontend-${AS_FRONTEND_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_FRONTEND="${REPOSITORY_SERVER}/appsuite/${AS_FRONTEND_VERSION}/appsuiteui"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-frontend" "${AS_REPO_FRONTEND}" 
    fi

}

# The backend repository may be required by some features like guard or documents
# It has to be tested in an clustered environment how this will work out. For singlenode it works ...
function writeBackendRepository {
    if [[ true == "${INSTALL_MIDDLEWARE}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_BACKEND="${REPOSITORY_SERVER}/backend-${AS_BACKEND_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_BACKEND="${REPOSITORY_SERVER}/appsuite/${AS_BACKEND_VERSION}/backend"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-middleware" "${AS_REPO_BACKEND}" 
    fi

}
function writeDriveClientRepositories {

    if [[ true == "${FEATURE_DRIVE_CLIENT_WINDOWS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_DRIVERESTRICTED="${REPOSITORY_SERVER}/driverestricted-${AS_DRIVERESTRICTED_VERSION}"
            AS_REPO_DRIVE_CLIENT_GENERIC="${REPOSITORY_SERVER}/drive-client-generic-${AS_DRIVE_CLIENT_GENERIC_VERSION}"
            AS_REPO_DRIVE_HELP="${REPOSITORY_SERVER}/drive-help-${AS_DRIVE_HELP_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_DRIVERESTRICTED="${REPOSITORY_SERVER}/appsuite/${AS_DRIVERESTRICTED_VERSION}/drive"
            AS_REPO_DRIVE_CLIENT_GENERIC="${REPOSITORY_SERVER}/drive/${AS_DRIVE_CLIENT_GENERIC_VERSION}/drive-client-windows"
            AS_REPO_DRIVE_HELP="${REPOSITORY_SERVER}/drive/${AS_DRIVE_HELP_VERSION}/drive-help"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi

        # appending second entry forcefully to repo file
        writeRepositoryFile "ox-drive" "${AS_REPO_DRIVERESTRICTED}" 
        writeRepositoryFile "ox-drive-client" "${AS_REPO_DRIVE_CLIENT_GENERIC}"
        writeRepositoryFile "ox-drive-help" "${AS_REPO_DRIVE_HELP}"
    fi
}

function writeUsmEasRepositories {

    if [[ true == "${FEATURE_USMEAS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_USM="${REPOSITORY_SERVER}/usm-${AS_USM_VERSION}"
            AS_REPO_EAS="${REPOSITORY_SERVER}/eas-${AS_EAS_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_EAS="${REPOSITORY_SERVER}/appsuite/${AS_EAS_VERSION}/mobilityconnector"
            AS_REPO_USM="${REPOSITORY_SERVER}/appsuite/${AS_USM_VERSION}/usm"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi

        # appending second entry forcefully to repo file
        writeRepositoryFile "ox-eas" "${AS_REPO_EAS}" 
        writeRepositoryFile "ox-usm" "${AS_REPO_USM}"
    fi

}

function writeGuardRepository {
    if [[ true == "${FEATURE_GUARD}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format            
            AS_REPO_GUARD="${REPOSITORY_SERVER}/guard-${AS_GUARD_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_GUARD="${REPOSITORY_SERVER}/guard/${AS_GUARD_VERSION}/guard"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-guard" "${AS_REPO_GUARD}" 
    fi

}

function writeOfficeRepository {
    if [[ true == "${FEATURE_DOCUMENTS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format            
            AS_REPO_OFFICE="${REPOSITORY_SERVER}/office-${AS_OFFICE_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_OFFICE="${REPOSITORY_SERVER}/appsuite/${AS_OFFICE_VERSION}/office"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-office" "${AS_REPO_OFFICE}" 
    fi
}
function writeOfficeWebRepository {
    if [[ true == "${FEATURE_DOCUMENTS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format            
            AS_REPO_OFFICE_FRONTEND="${REPOSITORY_SERVER}/oxhh/office-web-${AS_OFFICE_FRONTEND_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_OFFICE_FRONTEND="${REPOSITORY_SERVER}/appsuite/${AS_OFFICE_FRONTEND_VERSION}/office-web"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-office-web" "${AS_REPO_OFFICE_FRONTEND}" 
    fi
}
function writeDocumentsCollaborationRepository {
    if [[ true == "${FEATURE_DOCUMENTS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_OFFICE_COLLABORATION="${REPOSITORY_SERVER}/oxhh/documents-collaboration-${AS_OFFICE_COLLABORATION_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_OFFICE_COLLABORATION="${REPOSITORY_SERVER}/appsuite/${AS_OFFICE_COLLABORATION_VERSION}/documents-collaboration"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-documents-collaboration" "${AS_REPO_OFFICE_COLLABORATION}"
    fi
}
function writeDocumentconverterApiRepository {
    if [[ true == "${FEATURE_DOCUMENTCONVERTER}" ]] || [[ true == "${FEATURE_DOCUMENTS}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_DOCUMENTCONVERTER_API="${REPOSITORY_SERVER}/documentconverter-api-${AS_DOCUMENTCONVERTER_API_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_DOCUMENTCONVERTER_API="${REPOSITORY_SERVER}/appsuite/${AS_DOCUMENTCONVERTER_API_VERSION}/documentconverter-api"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-documentconverter-api" "${AS_REPO_DOCUMENTCONVERTER_API}"
    fi
}
function writeDocumentconverterRepositories {
    if [[ true == "${FEATURE_DOCUMENTCONVERTER}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_DOCUMENTCONVERTER="${REPOSITORY_SERVER}/documentconverter-${AS_DOCUMENTCONVERTER_VERSION}"
            AS_REPO_PDFTOOL="${REPOSITORY_SERVER}/oxhh/open-xchange-pdftool-${AS_PDFTOOL_VERSION}"
            AS_REPO_READERENGINE="${REPOSITORY_SERVER}/oxhh/readerengine-${AS_READERENGINE_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            # TODO: doc-conv/readerengine require always valid license. When installing from EXT without creds this may fail
            # 
            AS_REPO_DOCUMENTCONVERTER="${REPOSITORY_SERVER}/appsuite/${AS_DOCUMENTCONVERTER_VERSION}/documentconverter"
            AS_REPO_PDFTOOL="${REPOSITORY_SERVER}/appsuite/${AS_PDFTOOL_VERSION}/pdftool"
            AS_REPO_READERENGINE="${REPOSITORY_SERVER}/appsuite/${AS_READERENGINE_VERSION}/readerengine"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-documentconverter" "${AS_REPO_DOCUMENTCONVERTER}"
        writeRepositoryFile "ox-pdftool" "${AS_REPO_PDFTOOL}"
        writeRepositoryFile "ox-readerengine" "${AS_REPO_READERENGINE}"
    fi
}
function writeImageConverterRepository {
    if [[ true == "${FEATURE_IMAGECONVERTER}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_IMAGECONVERTER="${REPOSITORY_SERVER}/imageconverter-${AS_IMAGECONVERTER_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_IMAGECONVERTER="${REPOSITORY_SERVER}/appsuite/${AS_IMAGECONVERTER_VERSION}/imageconverter"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-imageconverter" "${AS_REPO_IMAGECONVERTER}"
    fi
}
function writeSpellcheckRepository {
    if [[ true == "${FEATURE_SPELLCHECK}" ]] || [[ true == "${FORCE_REPOS}" ]]; then
        # Take care if update dir has to be used        
        if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
            # internal buildservice format
            AS_REPO_SPELLCHECK="${REPOSITORY_SERVER}/oxhh/open-xchange-spellcheck-${AS_SPELLCHECK_VERSION}"
        elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then 
            # public repo format
            AS_REPO_SPELLCHECK="${REPOSITORY_SERVER}/appsuite/${AS_SPELLCHECK_VERSION}/spellcheck"
        else
            echo "ERROR: AS_REPO_SOURCE not set ... aborting !"
            exit 99
        fi
        writeRepositoryFile "ox-spellcheck" "${AS_REPO_SPELLCHECK}"
    fi
}
# TODO: Refactor below this line required!!
# ========================================================================================================================

function writeWeakforceRepository {
    echo "Determining weakforce repository locations ..."
    
    if [[ "${AS_REPO_SOURCE}" == "OBS" ]]; then
        if [[ -n "${AS_WEAKFORCE_VERSION}" ]]; then
            AS_REPO_WEAKFORCE=http://buildservice.open-xchange.com/backend-weakforced-${AS_WEAKFORCE_VERSION}/${DISTRO}/
        fi
    elif [[ "${AS_REPO_SOURCE}" == "EXT" ]]; then
        if [[ -n "${AS_WEAKFORCE_VERSION}" ]]; then
            AS_REPO_WEAKFORCE=https://software.open-xchange.com/products/weakforced/${AS_WEAKFORCE_VERSION}/backend-weakforced/${DISTRO}/
            if [[ -n "${AS_USER}" ]]; then
                AS_REPO_WEAKFORCE_UPDATES=https://${AS_USER}:${AS_PASS}@software.open-xchange.com/products/weakforced/${AS_WEAKFORCE_VERSION}/backend-weakforced/updates/${DISTRO}/
            fi
        fi
    fi

    if [[ "${WF_REPO_SOURCE}" == "OBS" ]]; then
        if [[ -n "${WF_VERSION}" ]]; then
            if [[ -n "${ANY_DEB}" ]]; then
                WF_REPO=http://10.50.3.45/wforce-${WF_VERSION}/${DISTRO_GENERIC}/${DIST_VERSION}/
                if [[ "${DIST}" == "DebianStretch" ]]; then
                    echo "deb http://repos.open-xchange.com/debian ${DIST_VERSION}-backports main contrib non-free" >> /etc/apt/sources.list
                    WF_3RDPARTY_REPO=http://10.50.3.45/wforce-3rdparty/${DISTRO_GENERIC}/${DIST_VERSION}/
                    cat >>/etc/apt/preferences.d/89_stretch-backports_default <<EOL
# # Allow libidn2-0 installed from stretch-backports
# libgetdns10 1.5.2 requires this
Package: libidn2-0
Pin: release n=stretch-backports
Pin-Priority: 500
EOL
                fi
            elif [[ -n "${ANY_RPM}" ]]; then
                WF_REPO=http://10.50.2.168/wforce-${WF_VERSION}/${DISTRO_GENERIC}/${DIST_VERSION}/RPMS/x86_64
                WF_3RDPARTY_REPO=http://10.50.2.168/wforce-3rdparty/${DISTRO_GENERIC}/${DIST_VERSION}/RPMS/x86_64
            fi
        fi
    elif [[ "${WF_REPO_SOURCE}" == "EXT" ]]; then
        if [[ -n "${WF_VERSION}" ]]; then
            if [[ -n "${WF_USER}" ]]; then
                if [[ -n "${ANY_DEB}" ]]; then
                    WF_REPO=https://${WF_USER}:${WF_PASS}@apt.dovecot.fi/wforce-${WF_VERSION}/${DISTRO_GENERIC}/${DIST_VERSION}/
                    if [[ "${DIST}" == "DebianStretch" ]]; then
                        echo "deb http://httpredir.debian.org/debian ${DIST_VERSION}-backports main contrib non-free" >> /etc/apt/sources.list
                        WF_3RDPARTY_REPO=https://${WF_USER}:${WF_PASS}@apt.dovecot.fi/wforce-3rdparty/${DISTRO_GENERIC}/${DIST_VERSION}/
                        cat >>/etc/apt/preferences.d/89_stretch-backports_default <<EOL
# # Allow libidn2-0 installed from stretch-backports
# libgetdns10 1.5.2 requires this
Package: libidn2-0
Pin: release n=stretch-backports
Pin-Priority: 500
EOL
                    fi
                elif [[ -n "${ANY_RPM}" ]]; then
                    WF_REPO=https://${WF_USER}:${WF_PASS}@yum.dovecot.fi/wforce-${WF_VERSION}/${DISTRO_GENERIC}/${DIST_VERSION}/RPMS/x86_64
                    WF_3RDPARTY_REPO=https://${WF_USER}:${WF_PASS}@yum.dovecot.fi/wforce-3rdparty/${DISTRO_GENERIC}/${DIST_VERSION}/RPMS/x86_64
                fi
            fi
        fi
    fi

    echo "Writing weakforce repository locations for current distribution ..."
    if [[ true == "${ANY_DEB}" ]]; then
        if [[ -n "${AS_REPO_WEAKFORCE}" ]]; then
            echo "deb ${AS_REPO_WEAKFORCE} /" >> /etc/apt/sources.list.d/weakforce.list
        fi
        if [[ -n "${AS_REPO_WEAKFORCE_UPDATES}" ]]; then
            echo "deb ${AS_REPO_WEAKFORCE_UPDATES} /" >> /etc/apt/sources.list.d/weakforce.list
        fi
        if [[ -n "${WF_REPO}" ]]; then
            echo "deb ${WF_REPO} ${DIST_VERSION} main" >> /etc/apt/sources.list.d/weakforce.list
        fi
        if [[ -n "${WF_3RDPARTY_REPO}" ]]; then
            echo "deb ${WF_3RDPARTY_REPO} ${DIST_VERSION} main" >> /etc/apt/sources.list.d/weakforce.list
        fi
    elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
        if [[ true == "${ANY_RHEL}" ]]; then :
            # TODO Add rhel-7-server-extras-rpms repository
            # Blocked by: https://jira.open-xchange.com/browse/RM-870
        elif [[ true == "${ANY_CENTOS}" ]]; then
            yum -y install epel-release
        fi
        if [[ -n "${AS_REPO_WEAKFORCE}" ]]; then
            {
            echo "[ox-appsuite-weakforce]"
            echo "name=OX App Suite Weakforce"
            echo "baseurl=${AS_REPO_WEAKFORCE}"
            echo "enabled=1"
            echo "proxy=_none_"
            } >> /etc/yum.repos.d/weakforce.repo
        fi
        if [[ -n "${AS_REPO_WEAKFORCE_UPDATES}" ]]; then
            {
            echo "[ox-appsuite-weakforce-updates]"
            echo "name=OX App Suite Weakforce Updates"
            echo "baseurl=${AS_REPO_WEAKFORCE_UPDATES}"
            echo "enabled=1"
            echo "proxy=_none_"
            } >> /etc/yum.repos.d/weakforce.repo
        fi
        if [[ -n "${WF_REPO}" ]]; then
            {
            echo "[weakforce]"
            echo "name=Weakforce"
            echo "baseurl=${WF_REPO}"
            echo "enabled=1"
            echo "proxy=_none_"
            } >> /etc/yum.repos.d/weakforce.repo
        fi
        if [[ -n "${WF_3RDPARTY_REPO}" ]]; then
            {
            echo "[weakforce-3rdparty]"
            echo "name=Weakforce 3rd Party"
            echo "baseurl=${WF_3RDPARTY_REPO}"
            echo "enabled=1"
            echo "proxy=_none_"
            } >> /etc/yum.repos.d/weakforce.repo
        fi
    fi
}
