#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
AS_BUILDKEY_OLD=http://software.open-xchange.com/oxbuildkey.pub
AS_BUILDKEY=https://software.open-xchange.com/0xDFD4BCF6-oxbuildkey.pub

# Installs the provided packages with the available package manager
function installPackages {
    if [ -z $DIST ]; then
        detectDistribution
    fi
    
    PACKAGES="$@"
    echo "Installing the following list of packages (this may take some time):"
    echo "${PACKAGES}"
    echo ""
    sleep 5
    
    if [[ true == "${ANY_DEB}" ]]; then
        apt-get -o Acquire::http::Timeout=300 -qq update
        apt-get -o Acquire::http::Timeout=300 -y install ${PACKAGES}
    elif [[ true == "${ANY_RHEL}" ]]; then
        #yum clean all
        yum makecache
        yum -y --setopt timeout=300 --setopt skip_missing_names_on_install=false install ${PACKAGES}
    elif [[ true == "${ANY_CENTOS}" ]]; then
        #yum clean all
        yum makecache
        yum -y --setopt timeout=300 --setopt skip_missing_names_on_install=false install ${PACKAGES}
    fi
}
function installPackagesRetry {
    # Sometimes package install will fail because of updated packages on the buildservice
    # Simply retrying the installation most probably will fix everything
    echo "Retrying installation on failure ..."
    INSTALLCOUNT=0
    while [[ ${INSTALLCOUNT} -lt 6 ]]; do
            # Calling the actual installPackages function ...
            installPackages "$1"
            if [[ $? -ne 0 ]]; then
                INSTALLCOUNT=$((INSTALLCOUNT+1))
                echo "Error while installing packages, retrying in 30s ($INSTALLCOUNT/5)."
                sleep 30
            else
                break
            fi
    done
    if [[ ${INSTALLCOUNT} -ge 5 ]]; then
        echo "Error while installing packages, aborting."
        exit 1
    fi
}

function addOxBuildKey {
    echo -n "Adding OX App Suite repository build key..."
    if [[ true == "${ANY_DEB}" ]]; then
        if [[ "${DIST}" == "DebianBookworm" ]]; then
            wget -qO - ${AS_BUILDKEY} | gpg --dearmor > /etc/apt/trusted.gpg.d/oxbuildkey.gpg
            wget -qO - ${AS_BUILDKEY_OLD} | gpg --dearmor > /etc/apt/trusted.gpg.d/oxbuildkey-old.gpg
        else
            wget -q ${AS_BUILDKEY} -O - | apt-key add -
            wget -q ${AS_BUILDKEY_OLD} -O - | apt-key add -
        fi
    elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
        rpm --import ${AS_BUILDKEY}
        rpm --import ${AS_BUILDKEY_OLD}
    fi
}

function preInstallActions {
    if [[ -z ${EXECUTED_preInstallActions} ]]; then
        if [[ true == "${ANY_DEB}" ]] && [ "OBS" == "${AS_REPO_SOURCE}" ]; then
            # Only set repos.ox.c if using internal buildservice ...
            echo "deb http://repos.open-xchange.com/debian ${DIST_VERSION} main contrib non-free" > /etc/apt/sources.list
            echo "deb http://repos.open-xchange.com/debian ${DIST_VERSION}-updates main contrib non-free" >> /etc/apt/sources.list
            apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 0E98404D386FA1D9
            apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 648ACFD622F3D138
        elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
            if [[ "${DIST}" == "RHEL8" ]]; then
                # Install the EPEL repo
                dnf -y install https://dl.fedoraproject.org/pub/epel/epel-release-latest-8.noarch.rpm
            fi
        fi

        echo "Executing preInstallActions ..."
        ADDITIONAL_PACKAGES="curl wget unzip"
        if [[ true == "${ANY_DEB}" ]]; then
            ADDITIONAL_PACKAGES="${ADDITIONAL_PACKAGES} apt-transport-https software-properties-common dirmngr gnupg2"
            if [[ true == "${INSTALL_DATABASE}" ]];then
                # Making MySQL installation unattended (Debian)
                echo "mysql mysql-server/root_password string ${DATABASE_ROOT_PASS}" | debconf-set-selections
                echo "mysql mysql-server/root_password_again string ${DATABASE_ROOT_PASS}" | debconf-set-selections
            fi
        elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
            ADDITIONAL_PACKAGES="${ADDITIONAL_PACKAGES} gnupg2"
        fi


        installPackagesRetry "${ADDITIONAL_PACKAGES}"

        export EXECUTED_preInstallActions=true
    else
        echo "preInstallActions already done ..."
    fi

}

function checkInstallDefaults {

    if [[ "${INSTALL_TYPE}" == "singlenode" ]]; then
        echo "Performing singlenode setup, checking defaults and setting them accordingly if missing ..."
        if [ -z ${INSTALL_FRONTEND} ]; then
            export INSTALL_FRONTEND=true
        fi

        if [ -z ${INSTALL_MIDDLEWARE} ]; then
            export INSTALL_MIDDLEWARE=true
        fi

        if [ -z ${FEATURE_GUARD} ]; then
            export FEATURE_GUARD=false
        fi

        if [ -z ${FEATURE_WEAKFORCE} ]; then
            export FEATURE_WEAKFORCE=false
        fi

        if [ -z ${FEATURE_DOCUMENTS} ]; then
            export FEATURE_DOCUMENTS=false
        fi

        if [ -z ${FEATURE_DOCUMENTCONVERTER} ]; then
            export FEATURE_DOCUMENTCONVERTER=false
        fi

        if [ -z ${INSTALL_DATABASE} ]; then
            export INSTALL_DATABASE=true
        fi  

        return 0
    else

        echo "Performing common setup, checking setup-defaults ..."
        # this simply checks if the install options are set
        if [ -z ${INSTALL_FRONTEND} ]; then
            export INSTALL_FRONTEND=false
        fi

        if [ -z ${INSTALL_MIDDLEWARE} ]; then
            export INSTALL_MIDDLEWARE=false
        fi

        if [ -z ${FEATURE_GUARD} ]; then
            export FEATURE_GUARD=false
        fi

        if [ -z ${FEATURE_WEAKFORCE} ]; then
            export FEATURE_WEAKFORCE=false
        fi

        if [ -z ${FEATURE_DOCUMENTS} ]; then
            export FEATURE_DOCUMENTS=false
        fi

        if [ -z ${FEATURE_DOCUMENTCONVERTER} ]; then
            export FEATURE_DOCUMENTCONVERTER=false
        fi

        if [ -z ${INSTALL_DATABASE} ]; then
            export INSTALL_DATABASE=false
        fi  
    fi
}


function checkInstalled {
    if [[ true == "${ANY_DEB}" ]]; then
        dpkg-query -l 'open-xchange-core' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            MIDDLEWARE_INSTALLED=true
        fi
        dpkg-query -l 'open-xchange-imageconverter-server' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            IMAGECONVERTER_INSTALLED=true
        fi
        dpkg-query -l 'open-xchange-documents-collaboration' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            DOCUMENTS_COLLABORATION_INSTALLED=true
        fi
        dpkg-query -l 'open-xchange-documentconverter-server' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            DOCUMENTCONVERTER_INSTALLED=true
        fi
        dpkg-query -l 'open-xchange-spellcheck' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            SPELLCHECK_INSTALLED=true
        fi
    elif [[ true == "${ANY_RPM}" ]]; then
        # rpm -qi open-xchange-core > /dev/null 2>&1

        rpm -qi 'open-xchange-core' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            MIDDLEWARE_INSTALLED=true
        fi
        rpm -qi 'open-xchange-imageconverter-server' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            IMAGECONVERTER_INSTALLED=true
        fi
        rpm -qi 'open-xchange-documents-collaboration' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            DOCUMENTS_COLLABORATION_INSTALLED=true
        fi
        rpm -qi 'open-xchange-documentconverter-server' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            DOCUMENTCONVERTER_INSTALLED=true
        fi
        rpm -qi 'open-xchange-spellcheck' > /dev/null 2>&1
        if [[ $? == 0 ]]; then
            SPELLCHECK_INSTALLED=true
        fi
    fi

    #     rpm -qi open-xchange-gui > /dev/null 2>&1
#     if [[ $? == 0 ]]; then
#         LEGACY_UI=true
#     fi
#     rpm -qi open-xchange-documents-backend > /dev/null 2>&1
#     if [[ $? == 0 ]]; then
#         AS_OFFICE=true
#     fi
#     rpm -qi open-xchange-documentconverter > /dev/null 2>&1
#     if [[ $? == 0 ]]; then
#         AS_OFFICE_DOCUMENT_PREVIEW=true
#     fi
}
