#!/bin/bash


SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done

if [ "$CONFIG_LOADED" != true ] ; then
  loadConfig
fi

STARTED_AT=$(date)
REINSTALL_SAME_VERSION=false

## Help text
show_usage() {
echo -n "
    -r | --reinstall    reinstall the same version of found ox packages
    
"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --foo) # non value argument
    INSTALL_FOO=true
    shift
    ;;
    -r|--reinstall) 
    export REINSTALL_SAME_VERSION=true
    shift
    ;;
    *) # unknown option
    echo "Unknonwn option: $1"
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


# source downgrade versions 
exportProperties ${SCRIPT_DIR}/versions.downgrade

checkRootPrivileges
detectDistribution

echo "===   (CTRL+C to cancel)   ==="
echo "Following versions will be used for the downgrade process:"
printenv | grep "^AS_"
echo "===   (CTRL+C to cancel)   ==="
sleep 5

# Disabling all repos
function disable_repos {
    if [[ true == "${ANY_DEB}" ]]; then
        APT_PATHS=( "/etc/apt/" "/etc/apt/sources.list.d/" )
        for j in "${APT_PATHS[@]}"; do
        cd "$j"
            for i in *.list; do
                if [[ -n $i ]]; then
                    mv "$i" "${i/.list/.list.disabled_by_appsuite_downgrade}"
                fi
            done
        done
    fi
}

# Enabling all repos
function enable_repos {
    if [[ true == "${ANY_DEB}" ]]; then
        APT_PATHS=( "/etc/apt/" "/etc/apt/sources.list.d/" )
        for j in "${APT_PATHS[@]}"; do
        cd "$j"
            for i in *.list.disabled_by_appsuite_downgrade; do
                if [[ -n $i ]]; then
                    mv "$i" "${i/.list.disabled_by_appsuite_downgrade/.list}"
                fi
            done
        done
    fi
}

disable_repos

# TODO: this still needs to be refactored somehow
writeRepositories
writeUsmEasRepository
writeGuardRepository

# Building package list
if [[ "${DIST}" == "DebianJessie" ]] || [[ "${DIST}" == "DebianStretch" ]] || [[ "${DIST}" == "DebianBuster" ]]; then
    apt-get clean
    apt-get -o Dir::Ignore-Files-Silently::="\.disabled_by_appsuite_downgrade$" update
    PACKAGES=$(dpkg --get-selections| grep "open-xchange.*[[:space:]]install"| cut -f1)
    for PKG in ${PACKAGES}; do
        INSTALLED_VER=$(apt-cache policy "$PKG"| grep "Installed:.*"| xargs| cut -d ' ' -f2)
        if [[ true == "${REINSTALL_SAME_VERSION}" ]]; then
            NEW_VER=$(apt-cache policy "$PKG"| grep -Eo "[*]{3}[\ ]([0-9]+\.[0-9]+\.[0-9]+\-[0-9]+)"| cut -d" " -f2| xargs)
        else
            NEW_VER=$(apt-cache policy "$PKG"| grep -Eo "[\ ]{2}[0-9]+\.[0-9]+\.[0-9]+\-[0-9]+"| xargs | sed -e "s/$INSTALLED_VER//g")
        fi
        if [[ -z "$NEW_VER" ]]; then
            echo "No downgradable version found for package '$PKG', removing currently installed version ($INSTALLED_VER)."
            REMOVE_PACKAGE_LIST+="${PKG} "
        else
            NEW_PACKAGE_LIST+="${PKG}=${NEW_VER} "
        fi
    done
    echo "Packages to remove: ${REMOVE_PACKAGE_LIST}"
    echo "Packages to downgrade: ${NEW_PACKAGE_LIST}"
    if [[ -z "$NEW_PACKAGE_LIST" ]]; then
        echo "No packages for downgrade, aborting. In case you tried to re-install the same version again, consider the REINSTALL_SAME_VERSION option."
        enable_repos
        exit 1
    fi
elif [[ "${DIST}" == "RHEL6" ]] || [[ "${DIST}" == "RHEL7" ]] || [[ "${DIST}" == "RHEL8" ]] || [[ "${DIST}" == "CENTOS6" ]] || [[ "${DIST}" == "CENTOS7" ]] || [[ "${DIST}" == "CENTOS8" ]]; then
    yum clean all
    yum -y install yum-utils
    PACKAGES=$(rpm -qa --qf "%{NAME}\n"| grep open-xchange)
    for PKG in ${PACKAGES}; do
        INSTALLED_VERSION=$(rpm -q --qf "%{VERSION}\n" "$PKG")
        INSTALLED_REV=$(rpm -q --qf "%{RELEASE}\n" "$PKG"| cut -d '_' -f1)
        INSTALLED_VER="$INSTALLED_VERSION-$INSTALLED_REV"
        NEW_VER=$(repoquery -q --disablerepo "*" --enablerepo "ox-*" --location "$PKG"| grep -Eo "[0-9]+\.[0-9]+\.[0-9]+")
        if [[ -z "$NEW_VER" ]]; then
            echo "No downgradable version found for package '$PKG', removing currently installed version ($INSTALLED_VER)."
            REMOVE_PACKAGE_LIST+="${PKG} "
        else
            NEW_PACKAGE_LIST+="${PKG} "
        fi
    done
fi
if [[ $? -ne 0 ]]; then
    echo "Error while downgrading packages, aborting."
    exit 1
fi

# Stopping App Suite before downgrading
stopAllServices 

# Downgrading
if [[ "${DIST}" == "DebianJessie" ]] || [[ "${DIST}" == "DebianStretch" ]] || [[ "${DIST}" == "DebianBuster" ]]; then
    if [[ -n "$REMOVE_PACKAGE_LIST" ]]; then
        dpkg --purge --force-depends ${REMOVE_PACKAGE_LIST}
        apt-get -o Dir::Ignore-Files-Silently::="\.disabled_by_appsuite_downgrade$" -f -y --force-yes install
    fi
    if [[ true == "${REINSTALL_SAME_VERSION}" ]]; then
        for PKG in ${NEW_PACKAGE_LIST}; do
            apt-get install -o Dir::Ignore-Files-Silently::="\.disabled_by_appsuite_downgrade$" -o Dpkg::Options::="--force-confold" --reinstall -y --force-yes ${PKG}
        done
    else
        apt-get install -o Dir::Ignore-Files-Silently::="\.disabled_by_appsuite_downgrade$" -o Dpkg::Options::="--force-confold" -y --force-yes  ${NEW_PACKAGE_LIST}
    fi
elif [[ "${DIST}" == "RHEL6" ]] || [[ "${DIST}" == "RHEL7" ]] || [[ "${DIST}" == "RHEL8" ]] || [[ "${DIST}" == "CENTOS6" ]] || [[ "${DIST}" == "CENTOS7" ]] || [[ "${DIST}" == "CENTOS8" ]]; then
    if [[ -n ${REMOVE_PACKAGE_LIST} ]]; then
        rpm -e --nodeps ${REMOVE_PACKAGE_LIST}
    fi
    if [[ true == "${REINSTALL_SAME_VERSION}" ]]; then
        yum -y reinstall ${NEW_PACKAGE_LIST}
    else
        yum -y --tolerant downgrade ${NEW_PACKAGE_LIST}
    fi
fi
if [[ $? -ne 0 ]]; then
    enable_repos
    echo "Downgrade failed, good luck."
    exit 1
else
    enable_repos
    echo "Downgrade done, re-starting services..."
fi

startAllServices
waitTillAppsuiteReady

FINISHED_AT=$(date)
echo "====================================================================================="
echo "Started at:   $STARTED_AT"
echo "Finished at:  $FINISHED_AT"


echo "
Note: There may now be left-over repositories which contain newer packages. Please take care of them manually.

Downgrade complete, thanks for using OX App Suite. Have a lot of fun!
"
