#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Markus Wagner <markus.wagner@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
checkRootPrivileges
detectDistribution

if [ -z ${JAVA_JDK_VERSION} ]; then
    JAVA_JDK_VERSION=8
fi


## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;

    # --repo-guard)
    # OX_REPO_GUARD="$2"
    # echo "WARNING: Using $OX_REPO_GUARD as guard repository source"
    # shift 
    # shift 
    # ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

preInstallActions

PACKAGES=""

if [[ true == "${ANY_DEB}" ]]; then
    echo "Adding packages.adoptium.net build key to apt ..."
    wget -qO - https://packages.adoptium.net/artifactory/api/gpg/key/public | apt-key add -

    add-apt-repository --yes https://packages.adoptium.net/artifactory/deb

    PACKAGES="temurin-${JAVA_JDK_VERSION}-jdk"
elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
    {
    echo "[Adoptium]"
    echo "name=Adoptium"
    echo "baseurl=https://packages.adoptium.net/artifactory/rpm/${DISTRO_GENERIC}/${DIST_VERSION}/$(uname -m)"
    echo "enabled=1"
    echo "gpgcheck=1"
    echo "gpgkey=https://packages.adoptium.net/artifactory/api/gpg/key/public"
            } > /etc/yum.repos.d/adoptium.repo


    PACKAGES="temurin-${JAVA_JDK_VERSION}-jdk"
fi

# if ! [ -x "$(command -v java)" ]; then
#     echo "Adding nc package to list of packages ..."
#     PACKAGES="nc ${PACKAGES}"
# fi

installPackages ${PACKAGES}
