#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
checkRootPrivileges
if [ "$CONFIG_LOADED" != true ] ; then
  loadConfig
fi
## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]
    
    --init-singlenode forces init process after frontend installation for singlenode/localhost nodes only


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

writeFrontendRepository
writeBackendRepository
PACKAGES="open-xchange-appsuite
open-xchange-appsuite-help*
open-xchange-appsuite-l10n-en-us
open-xchange-appsuite-l10n-de-de
open-xchange-appsuite-manifest
open-xchange-guidedtours"
installPackagesRetry "${PACKAGES}"

# # Install frontend realted documents packages
# ${SCRIPT_DIR}/../features/documents.sh --install --frontend

echo "Enabling Apache httpd modules..."
if [[ true == "${ANY_DEB}" ]]; then

    if [[ true == "${ANY_DEB}" ]]; then
        a2dissite default-ssl 1> /dev/null
        a2dissite 000-default 1> /dev/null
    fi
    a2enmod proxy 1> /dev/null
    a2enmod proxy_balancer 1> /dev/null
    a2enmod proxy_http 1> /dev/null
    a2enmod expires 1> /dev/null
    a2enmod deflate 1> /dev/null
    a2enmod headers 1> /dev/null
    a2enmod rewrite 1> /dev/null
    a2enmod ssl 1> /dev/null
    a2enmod proxy_wstunnel 1> /dev/null
elif [[ true == "${ANY_RHEL}" ]] || [[ true == "${ANY_CENTOS}" ]]; then
    yum install -y mod_ssl openssl
    mv "${HTTPD_CONF_PATH}/welcome.conf" "${HTTPD_CONF_PATH}/welcome.DISABLED"  2> /dev/null || true

    echo "Removing default virtual host from config ..."
    #mv "${HTTPD_CONF_PATH}/ssl.conf" "${HTTPD_CONF_PATH}/ssl.DISABLED"
    sed -i.bak '/<VirtualHost .*>/,/<\/VirtaulHost>/d' ${HTTPD_CONF_PATH}/ssl.conf

    if [[ "${DIST}" == "RHEL6" ]]; then
        service httpd start
        echo "Adding services to autostart..."
        chkconfig --level 345 httpd on
        
    elif [[ "${DIST}" == "RHEL7" ]] || [[ "${DIST}" == "RHEL8" ]] ; then
        systemctl start httpd.service
        echo "Adding services to autostart..."
        systemctl enable httpd.service
    fi
    
    if [[ "${DIST}" == "RHEL8" ]] || [[ "${DIST}" == "CENTOS8" ]]; then
        /usr/sbin/setsebool -P httpd_can_network_connect 1
    fi

fi

# Apache 2.4 specific modules
if [[ true == "${ANY_DEB}" ]]; then
    a2enmod access_compat 1> /dev/null
    a2enmod slotmem_shm 1> /dev/null
    a2enmod lbmethod_byrequests 1> /dev/null
    a2enmod filter 1> /dev/null
fi

echo "Adding default configuration ..."
cp -v ${SCRIPT_DIR}/../config/frontend/conf/*.conf ${HTTPD_CONF_PATH}

# Copy sites related config and substitute the ${HTTPD_WWWROOT_PATH} variable with its actual value ...
#cp -v ${SCRIPT_DIR}/../config/frontend/sites/*.conf ${HTTPD_SITES_PATH}
echo "Creating http/https config ..."
envsubst < ${SCRIPT_DIR}/../config/frontend/sites/ox-http.conf > ${HTTPD_SITES_PATH}/ox-http.conf
envsubst < ${SCRIPT_DIR}/../config/frontend/sites/ox-https.conf > ${HTTPD_SITES_PATH}/ox-https.conf

${SCRIPT_DIR}/../config/frontend/create-self-signed-ssl.sh
