#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
detectDistribution
# INSTALL_FOO=false
# INSTALL_BAR=false

## Help text
show_usage() {
echo -n "

"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    # --foo) # non value argument
    # INSTALL_FOO=true
    # shift
    # ;;
    # --bar) # argument with value 
    # INSTALL_BAR=true
    # BAR_VAL=$2
    # shift
    # shift
    # ;;
    *) # unknown option
    echo "Unknonwn option: $1"
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


# 
# if [[ "${INSTALL_FOO}" = true  ]]; then
#     PACKAGES="${PACKAGES} "
# fi

# # 
# if [[ "${INSTALL_BAR}" = true  ]]; then
#     PACKAGES="${PACKAGES} "
# fi



if [[ "${DIST}" == "DebianBuster" ]] || [[ "${DIST}" == "DebianBullseye" ]] || [[ "${DIST}" == "DebianBookworm" ]]; then
    # Use adoptium on buster
    echo "Using adoptium by default!"
    ${SCRIPT_DIR}/install-adoptium.sh

elif [[ "${INSTALL_JAVA_ADOPTIUM}" == "true" ]]; then
    echo "INSTALL_JAVA_ADOPTIUM is set to true, using Adoptium instead of the distrubution provided java"
    echo "WARNING: This may not work on older OX Versions as jre-headless is required but not provided by adoptium."
    echo "WARNING: In case the setup fails take care of this possible situation!!"
    sleep 5
    ${SCRIPT_DIR}/install-adoptium.sh
else
    # In most cases the distribution will ship some java 8 packacges, for debian buster they have to be fetched from sid repositories
    echo "The current distribution provides some compatible java packages ... exitting!"
    exit 0
fi


