#!/bin/bash
#
# Copyright (C) Open-Xchange GmbH, Germany <info@open-xchange.com>
# 
# This file is part of OX Automation.
#
# OX Automation is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# OX Automation is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with OX Automation. If not, see <http://www.gnu.org/licenses/>.
#
#
# Authors:
# Benedikt Kroening <benedikt.kroening@open-xchange.com>
#
set -e
SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done
checkRootPrivileges

## Help text
show_usage() {
echo -n "
  $0 [OPTIONS]


"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --guard)
    FEATURE_GUARD=true
    shift
    ;;
    --documents)
    FEATURE_DOCUMENTS=true
    shift
    ;;
    *)    # unknown option
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters

writeFrontendRepository
writeBackendRepository
PACKAGES="open-xchange
open-xchange-admin
open-xchange-admin-soap
open-xchange-appsuite-backend
open-xchange-authentication-database
open-xchange-authorization-standard
open-xchange-calendar-printing
open-xchange-core
open-xchange-dav
open-xchange-deputy
open-xchange-drive
open-xchange-drive-comet
open-xchange-file-distribution
open-xchange-file-storage-boxcom
open-xchange-file-storage-dropbox
open-xchange-file-storage-googledrive
open-xchange-file-storage-mail
open-xchange-file-storage-onedrive
open-xchange-file-storage-webdav
open-xchange-grizzly
open-xchange-imap
open-xchange-l10n-en-us
open-xchange-l10n-de-de
open-xchange-mailfilter
open-xchange-manage-group-resource
open-xchange-messaging
open-xchange-multifactor
open-xchange-oauth
open-xchange-osgi
open-xchange-passwordchange-database
open-xchange-pns-transport-websockets
open-xchange-pop3
open-xchange-push-imapidle
open-xchange-rest
open-xchange-sessionstorage-hazelcast
open-xchange-smtp
open-xchange-subscribe
open-xchange-system
open-xchange-unifiedmail
open-xchange-websockets-grizzly
open-xchange-xerces"

installPackagesRetry "${PACKAGES}"
# Post-install actions
if [[ "${DIST}" == "CENTOS7" ]] || [[ "${DIST}" == "RHEL7" ]] || [[ "${DIST}" == "RHEL8" ]] || [[ "${DIST}" == "CENTOS8" ]]; then
    chkconfig open-xchange on
elif [[ "${DIST}" == "CENTOS6" ]] || [[ "${DIST}" == "RHEL6" ]]; then
    chkconfig --level 345 open-xchange on
fi
