#!/bin/bash


SCRIPT_DIR="$( cd "$(dirname "$0")" ; pwd -P)"
# sourcing some commonly used functions and executing basic checks
for f in ${SCRIPT_DIR}/../lib/*.bash; do source "$f"; done

if [ "$CONFIG_LOADED" != true ] ; then
  loadConfig
fi

STARTED_AT=$(date)

## Help text
show_usage() {
echo -n "
    
"
}

### reading config from command line; overriding defaults
POSITIONAL=()
while [[ $# -gt 0 ]]
do
key="$1"

case $key in
    -h|--help)
    show_usage
    exit 0
    shift
    ;;
    --debug)
    echo "WARNING: Debug flag set (--debug)"
    set -x
    shift
    ;;
    --foo) # non value argument
    INSTALL_FOO=true
    shift
    ;;

    *) # unknown option
    echo "Unknonwn option: $1"
    POSITIONAL+=("$1") # save it in an array for later
    shift 
    ;;
esac
done
set -- "${POSITIONAL[@]}" # restore positional parameters


# source upgrade versions 
exportProperties ${SCRIPT_DIR}/versions.upgrade

checkRootPrivileges
detectDistribution

echo "===   (CTRL+C to cancel)   ==="
echo "Following versions will be used for the upgrade process:"
printenv | grep "^AS_"
echo "===   (CTRL+C to cancel)   ==="
sleep 5

# Disabling all repos
function disable_repos {
    if [[ true == "${ANY_DEB}" ]]; then
        APT_PATHS=( "/etc/apt/" "/etc/apt/sources.list.d/" )
        for j in "${APT_PATHS[@]}"; do
        cd "$j"
            for i in *.list; do
                if [[ -n $i ]]; then
                    mv "$i" "${i/.list/.list.disabled_by_appsuite_upgrade}"
                fi
            done
        done
    fi
}

# Enabling all repos
function enable_repos {
    if [[ true == "${ANY_DEB}" ]]; then
        APT_PATHS=( "/etc/apt/" "/etc/apt/sources.list.d/" )
        for j in "${APT_PATHS[@]}"; do
        cd "$j"
            for i in *.list.disabled_by_appsuite_upgrade; do
                if [[ -n $i ]]; then
                    mv "$i" "${i/.list.disabled_by_appsuite_upgrade/.list}"
                fi
            done
        done
    fi
}

disable_repos

# TODO: this still needs to be refactored somehow
writeRepositories
writeUsmEasRepository
writeGuardRepository
addOxBuildKey

# stopping services
stopAllServices

if [[ "${DIST}" == "DebianJessie" ]] || [[ "${DIST}" == "DebianStretch" ]] || [[ "${DIST}" == "DebianBuster" ]]; then
    #export UCF_FORCE_CONFFNEW=1
    apt-get clean
    apt-get update
    apt-get -y -o Dpkg::Options::="--force-confold" dist-upgrade
    apt-get -y dist-upgrade
elif [[ "${DIST}" == "RHEL6" ]] || [[ "${DIST}" == "RHEL7" ]] || [[ "${DIST}" == "RHEL8" ]] || [[ "${DIST}" == "CENTOS6" ]] || [[ "${DIST}" == "CENTOS7" ]] || [[ "${DIST}" == "CENTOS8" ]]; then
    yum clean all
    yum -y upgrade
fi


startAllServices
waitTillAppsuiteReady

echo "Trying to execute all updates tasks ..."
/opt/open-xchange/sbin/runallupdate -A ${OX_ADMINMASTER_USER} -P ${OX_ADMINMASTER_PASS}

FINISHED_AT=$(date)
echo "====================================================================================="
echo "Started at:   $STARTED_AT"
echo "Finished at:  $FINISHED_AT"

echo "
Update complete, thanks for using OX App Suite. Have a lot of fun!
"
